Functions to query data from MySQL and parse the query results.
Functions to query data from MySQL and parse the query results.
(binlog-position db-spec)Query binary log position from MySQL.
Query binary log position from MySQL.
(db-spec {:keys [host port db user password subname]})Build a db spec from configuration for connecting with database.
Build a db spec from configuration for connecting with database.
(fetch-table-cols db-spec db table)Query table column metadata for db and table.
Query table column metadata for db and table.
(parse-table-schema cols)Parse the cols column metadata into a table schema presentation.
Parse the cols column metadata into a table schema presentation.
(show-binlog-positions db-spec)List all available binary log positions.
List all available binary log positions.
(stream-table db-spec {:keys [table id-fn]} ch)Stream the contents of a given database table to a core.async channel. Designed to work as async-fn of clojure.core.async/pipeline-async meaning that takes output channel as last argument and closes the channel after streaming is complete..
Stream the contents of a given database table to a core.async channel. Designed to work as async-fn of clojure.core.async/pipeline-async meaning that takes output channel as last argument and closes the channel after streaming is complete..
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |